@@ -1958,7 +1958,7 @@ impl<'a> Formatter for PrettyFormatter<'a> {
     {
         self.current_indent += 1;
         self.has_value = false;
-        writer.write_all(b"[")
+        writer.write_all(b"<<")
     }
 
     #[inline]
@@ -1973,7 +1973,7 @@ impl<'a> Formatter for PrettyFormatter<'a> {
             tri!(indent(writer, self.current_indent, self.indent));
         }
 
-        writer.write_all(b"]")
+        writer.write_all(b">>")
     }
 
     #[inline]
